---
title: Dive Services
author:
date: 2025-06-24
...

# Dive Services {#dive-services}

## plugins.dive.range (`DATA`) {#range}

Parametrization of the exploration range.


> [`range`](#range)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"backward"` (opt.) | _number_ | range for the write dependencies |
| `"forward"` (opt.) | _number_ | range for the read dependencies |


## plugins.dive.explorationWindow (`DATA`) {#explorationwindow}

Global parametrization of the exploration.


> [`explorationWindow`](#explorationwindow)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"perception"` | [`range`](index.md#range)  | how far dive will explore from root nodes ; must be a finite range |
| `"horizon"` | [`range`](index.md#range)  | range beyond which the nodes must be hidden |


## plugins.dive.nodeId (`DATA`) {#nodeid}

A node identifier in the graph


> [`nodeId`](#nodeid)  `::=` _number_
  

## plugins.dive.callsite (`DATA`) {#callsite}

callsite


> [`callsite`](#callsite)  `::=` `{` `"fun"` `:` _string_ , `"instr"` `:`
  _number_ | `"global"` `}`
  

## plugins.dive.callstack (`DATA`) {#callstack}

The callstack context for a node


> [`callstack`](#callstack)  `::=` [`callsite`](index.md#callsite)  `[]`
  

## plugins.dive.nodeLocality (`DATA`) {#nodelocality}

The description of a node locality


> [`nodeLocality`](#nodelocality)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"file"` | _string_ | file |
| `"callstack"` (opt.) | [`callstack`](index.md#callstack)  | callstack |


## plugins.dive.nodeKind (`DATA`) {#nodekind}

The nature of a node


> [`nodeKind`](#nodekind)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Scalar | `"scalar"` | a single memory cell |
| Composite | `"composite"` | a memory bloc containing cells |
| Scattered | `"scattered"` | a set of memory locations designated by an lvalue |
| Unknown | `"unknown"` | an unresolved memory location |
| Alarm | `"alarm"` | an alarm emitted by Frama-C |
| Absolute | `"absolute"` | a memory location designated by a range of adresses |
| String | `"string"` | a string literal |
| Error | `"error"` | a placeholder node when an error prevented the generation process |
| Const | `"const"` | a numeric constant literal |


## plugins.dive.nodeKindTags (`GET`) {#nodekindtags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](../../kernel/data.md#tag)  `[]`
  

## plugins.dive.taint (`DATA`) {#taint}

Taint of a memory location


> [`taint`](#taint)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Untainted | `"untainted"` | not tainted by anything |
| Indirect | `"indirect"` | tainted by control |
| Direct | `"direct"` | tainted by data |


## plugins.dive.taintTags (`GET`) {#tainttags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](../../kernel/data.md#tag)  `[]`
  

## plugins.dive.exploration (`DATA`) {#exploration}

The computation state of a node read or write dependencies


> [`exploration`](#exploration)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Yes | `"yes"` | all dependencies have been computed |
| Partial | `"partial"` | some dependencies have been explored |
| No | `"no"` | dependencies have not been computed |


## plugins.dive.explorationTags (`GET`) {#explorationtags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](../../kernel/data.md#tag)  `[]`
  

## plugins.dive.nodeSpecialRange (`DATA`) {#nodespecialrange}

A qualitative description of the range of values that this node can take.


> [`nodeSpecialRange`](#nodespecialrange)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Empty | `"empty"` | no value ever computed for this node |
| Singleton | `"singleton"` | this node can only have one value |
| Wide | `"wide"` | this node can take almost all values of its type |


## plugins.dive.nodeSpecialRangeTags (`GET`) {#nodespecialrangetags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](../../kernel/data.md#tag)  `[]`
  

## plugins.dive.nodeRange (`DATA`) {#noderange}

A qualitative or quantitative description of the range of values that this node can take.


> [`nodeRange`](#noderange)  `::=` _number_ |
  [`nodeSpecialRange`](index.md#nodespecialrange) 
  

## plugins.dive.node (`DATA`) {#node}

> [`node`](#node)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"id"` | [`nodeId`](index.md#nodeid)  | id |
| `"label"` | _string_ | label |
| `"nkind"` | [`nodeKind`](index.md#nodekind)  | nkind |
| `"locality"` | [`nodeLocality`](index.md#nodelocality)  | locality |
| `"is_root"` | _boolean_ | is_root |
| `"backward_explored"` | [`exploration`](index.md#exploration)  | backward_explored |
| `"forward_explored"` | [`exploration`](index.md#exploration)  | forward_explored |
| `"writes"` | [`marker`](../../kernel/ast.md#marker)  `[]` | writes |
| `"values"` (opt.) | _string_ | values |
| `"range"` | [`nodeRange`](index.md#noderange)  | range |
| `"type"` (opt.) | _string_ | type |
| `"taint"` (opt.) | [`taint`](index.md#taint)  | taint |


## plugins.dive.dependency (`DATA`) {#dependency}

The dependency between two nodes


> [`dependency`](#dependency)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"id"` | _number_ | id |
| `"src"` | [`nodeId`](index.md#nodeid)  | src |
| `"dst"` | [`nodeId`](index.md#nodeid)  | dst |
| `"dkind"` | _string_ | dkind |
| `"origins"` | [`marker`](../../kernel/ast.md#marker)  `[]` | origins |


## plugins.dive.element (`DATA`) {#element}

A graph element, either a node or a dependency


> [`element`](#element)  `::=` [`node`](index.md#node)  |
  [`dependency`](index.md#dependency) 
  

## plugins.dive.graph (`ARRAY`) {#graph}

The graph being built as a set of vertices and edges


## plugins.dive.signalGraph (`SIGNAL`) {#signalgraph}

Signal for array [`graph`](#graph) 


## plugins.dive.graphData (`DATA`) {#graphdata}

Data for array rows [`graph`](#graph) 


> [`graphData`](#graphdata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | `$graph` | Entry identifier. |
| `"element"` | [`element`](index.md#element)  | a graph element |


## plugins.dive.fetchGraph (`GET`) {#fetchgraph}

Data fetcher for array [`graph`](#graph) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"reload"` | _boolean_ | array fully reloaded |
| `"removed"` | `$graph` `[]` | removed entries |
| `"updated"` | [`graphData`](index.md#graphdata)  `[]` | updated entries |
| `"pending"` | _number_ | remaining entries to be fetched |


## plugins.dive.reloadGraph (`GET`) {#reloadgraph}

Force full reload for array [`graph`](#graph) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## plugins.dive.window (`SET`) {#window}

Set the exploration window


> _input_ `::=` [`explorationWindow`](index.md#explorationwindow) 
  

> _output_ `::=` _null_
  

## plugins.dive.clear (`EXEC`) {#clear}

Erase the graph and start over with an empty one


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## plugins.dive.add (`EXEC`) {#add}

Add a node to the graph


> _input_ `::=` [`marker`](../../kernel/ast.md#marker) 
  

> _output_ `::=` [`nodeId`](index.md#nodeid)  `?`
  

## plugins.dive.explore (`EXEC`) {#explore}

Explore the graph starting from an existing vertex


> _input_ `::=` [`nodeId`](index.md#nodeid) 
  

> _output_ `::=` _null_
  

## plugins.dive.show (`EXEC`) {#show}

Show the dependencies of an existing vertex


> _input_ `::=` [`nodeId`](index.md#nodeid) 
  

> _output_ `::=` _null_
  

## plugins.dive.hide (`EXEC`) {#hide}

Hide the dependencies of an existing vertex


> _input_ `::=` [`nodeId`](index.md#nodeid) 
  

> _output_ `::=` _null_
  